<?php

namespace FiloBlu\ExtAmastyGeoipRedirect\Block;

class Popup extends \Magento\Framework\View\Element\Template {

    public $_helper;
    protected $_continent;
    protected $_countryContinent;

    /**
     * @var \Magento\Framework\App\Config\ScopeConfigInterface
     */
    protected $scopeConfig;
    protected $_storeManager;
    protected $_coreRegistry = null;

    public function __construct(
    \Magento\Framework\View\Element\Template\Context $context, array $data = [], \FiloBlu\ExtAmastyGeoipRedirect\Helper\Data $helper, \FiloBlu\ExtAmastyGeoipRedirect\Model\Continent $continent, \FiloBlu\ExtAmastyGeoipRedirect\Model\CountryContinent $countryContinent, \Magento\Framework\Registry $registry
    ) {
        $this->_helper = $helper;
        $this->_continent = $continent;
        $this->_countryContinent = $countryContinent;
        $this->scopeConfig = $context->getScopeConfig();
        $this->_storeManager = $context->getStoreManager();
        $this->_coreRegistry = $registry;

        parent::__construct($context, $data);
    }

    public function getAllCountries() {

        $result = array();
        $resultAllCountries = array();
        $resultAllContinentCountry = array();

        if ($this->scopeConfig->getValue('amgeoipredirect/country_store/enable_store')) {
            $allStores = $this->_storeManager->getStores();
            foreach ($allStores as $store) {
                $currentStoreUrl = str_replace('&amp;', '&', $store->getCurrentUrl(false));
                $redirectStoreUrl = trim($currentStoreUrl, '/');

                $countries = $this->scopeConfig->getValue('amgeoipredirect/country_store/affected_countries', \Magento\Store\Model\ScopeInterface::SCOPE_STORES, $store->getId());
                $countries = explode(",", $countries);

                foreach ($countries as $country) {
                    if ($country) {
                        $continent = $this->_countryContinent->getContinentByCountry($country);

                        if ($this->showPopup()) {
                            $continentName = $continent->getContinent();
                            $countryName = $this->_helper->getCountryName($country, "en_US");
                        } else {
                            $continentName = _($continent->getContinent());
                            $countryName = $this->_helper->getCountryName($country);
                        }

                        array_push($resultAllCountries, ["label" => $countryName, "country_id" => $country, "store_id" => $store->getId(), "url" => $store->getBaseUrl()]);

                        $countryData = [
                            "country_id" => $country,
                            "store_id" => $store->getId(),
                            "url" => $store->getBaseUrl()
                        ];


                        if (!isset($resultAllContinentCountry[$continentName])) {
                            $resultAllContinentCountry[$continentName]["position"] = $continent->getPosition();
                        }
                        if (!isset($resultAllContinentCountry[$continentName]["countries"][$countryName])) {
                            $resultAllContinentCountry[$continentName]["countries"][$countryName] = $countryData;
                        } else {
                            array_push($resultAllContinentCountry[$continentName]["countries"][$countryName], $countryData);
                        }
                    }
                }
            }
        }

        // Order by continent position
        $this->aasort($resultAllContinentCountry, "position");

        // Order by country name
        foreach ($resultAllContinentCountry as $continent => $continentData) {
            ksort($continentData["countries"]);
            $resultAllContinentCountry[$continent]["countries"] = $continentData["countries"];
        }

        // Order Countries
        $this->aasort($resultAllCountries, "label");

        $result["continentcountry"] = $resultAllContinentCountry;
        $result["countries"] = $resultAllCountries;

        return $result;
    }

    public function showPopup() {
        return $this->_coreRegistry->registry('filoblu_geoip_popup_show');
    }

    public function getCurrentCountryCode() {
        return $this->_helper->getCountryCookie();
    }
    
    protected function aasort(&$array, $key) {
        $sorter = array();
        $ret = array();
        reset($array);
        foreach ($array as $ii => $va) {
            $sorter[$ii] = $va[$key];
        }
        asort($sorter);
        foreach ($sorter as $ii => $va) {
            $ret[$ii] = $array[$ii];
        }
        $array = $ret;
    }

    protected function _toHtml() {
        if (!$this->scopeConfig->getValue('amgeoipredirect/general/enable')) {
            return "";
        } else {
            return parent::_toHtml();
        }
    }

}
